suraj-goel commented on PR #20519:
URL: https://github.com/apache/druid/pull/20519#issuecomment-6054198307

   > Thanks, @suraj-goel ! Before merging off this PR, could you also confirm 
if this change has affected the runtime of this test in anyway? Just curious.
   
    Thanks @kfaraz! Yes, it's faster. Measured locally:
   - Running only this test (including embedded cluster startup): ~23.4s → 
~14.4s
   - Supervisor submit → last segment handoff: ~10.7s → ~1.75s


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to